
if not exists (select * from dbo.sysobjects 
                   where id = object_id(N'dbo.plantillas_caja')
                   and OBJECTPROPERTY(id, N'IsUserTable') = 1)
                   
CREATE TABLE [dbo].[plantillas_caja](
	[idCaja] [bigint] IDENTITY(1,1) NOT NULL,
	[idEmpresa] [bigint] NULL,
	[plantilla_id] [bigint] NULL,
	[codigo] [bigint] NULL,
	[fechaInicio] [datetime] NULL,
	[fechaFinal] [datetime] NULL,
	[Sueldo] [decimal](18, 2) NULL,
	[estatus][varchar](10) NULL,
	[centro][bigint] NULL,
	[ocupacion][bigint] NULL
 CONSTRAINT [PK_plantillas_caja] PRIMARY KEY CLUSTERED 
(
	[idCaja] ASC
) ON [PRIMARY]
) ON [PRIMARY]

GO

IF not EXISTS(select syscolumns.name  from syscolumns 
	left join sysobjects on syscolumns.id=sysobjects.id
	where syscolumns.name = 'activa' and sysobjects.name='plantillas')
	Alter table dbo.plantillas add activa varchar(1) null    
	              
GO

update plantillas set activa ='N' where activa is null
GO


/**************************************************************************************************
 * Name          : plantillasReporteCCxPlantilla
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : Viernes, 13 de Abril de 2012
 * Parameters    : @sistema = sistema al que se quiere acceder
 *               : @usuario = usuario del sistema
                 : @funcion = funcion del sistema que se quiere acceder 
                 : @opcion  = opcion del sistema que se quiere acceder              
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasReporteCCxPlantilla'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasReporteCCxPlantilla
GO

CREATE PROCEDURE dbo.plantillasReporteCCxPlantilla
	@idPlantilla bigint,
	@companyID bigint
    
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
  
	SELECT
		empresas.empresa,
		empresas.registro_patronal,
		empresas.rfc_empresa,
		empresas.nombre_empresa,
		Plantillas.plantilla_id,
		Plantillas.nombre,
		Plantillas_Centros.centro,
		centros.nomdepto
	FROM
		((empresas empresas INNER JOIN Plantillas Plantillas ON
			empresas.empresa = Plantillas.empresa)
		INNER JOIN Plantillas_Centros Plantillas_Centros ON
			Plantillas.empresa = Plantillas_Centros.empresa AND
			Plantillas.plantilla_id = Plantillas_Centros.plantilla_id)
		INNER JOIN centros centros ON
			Plantillas_Centros.centro = centros.centro AND
			Plantillas_Centros.empresa = centros.empresa
	WHERE
		empresas.empresa = 6
	ORDER BY
		empresas.empresa ASC,
		Plantillas_Centros.plantilla_id ASC
    
go


/**************************************************************************************************
 * Name          : plantillasEliminaPlantilla
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 4 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasEliminaPlantilla'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasEliminaPlantilla
GO

CREATE PROCEDURE dbo.plantillasEliminaPlantilla
	@idPlantilla bigint,
	@companyID bigint
    
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
  
	 delete from Plantillas_caja   where plantilla_id = @idPlantilla and idempresa =@companyID    
	 delete from plantilla_propuestos where idplantilla  = @idPlantilla and empresa =@companyID               
     delete from Plantillas_Puestos   where plantilla_id = @idPlantilla and empresa =@companyID                       
     delete from plantillas_centros   where plantilla_id = @idPlantilla and empresa =@companyID                                
     delete from plantillas  where plantilla_id = @idPlantilla and empresa =@companyID   
     
go


/**************************************************************************************************
 * Name          : plantillasEliminaPlantilla
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 8 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasCargaCaja'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasCargaCaja
GO

CREATE PROCEDURE dbo.plantillasCargaCaja
(	@idCaja bigint,
	@idPlantilla bigint,
	@idEmpresa bigint,
	@idPuesto bigint,
	@centro varchar(250)
 )   
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
      
    declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048)   
      
      
	set @selectStatement=' SELECT convert(real,plantillas_caja.idCaja,2)
 						  ,convert(real,plantillas_caja.codigo,2)
						  ,rtrim(empleados.nombre) + '' '' + rtrim(empleados.ap_paterno) + '' '' + rtrim(empleados.ap_materno) as nombre
						  ,convert(varchar(10),plantillas_caja.fechaInicio,103) as fechainicio
						  ,convert(varchar(10),plantillas_caja.fechaFinal,103) as fechafinal
						  ,plantillas_caja.Sueldo
						  ,plantillas_caja.estatus
						  ,plantillas_caja.fechaInicio
						  ,plantillas_caja.fechafinal'
						  
	set @fromStatement= ' FROM plantillas_caja inner join empleados on plantillas_caja.codigo=empleados.codigo' +
						' and  plantillas_caja.idempresa=empleados.empresa ' +
						' inner join llaves on  llaves.codigo=empleados.codigo ' + 
						' and llaves.empresa= empleados.empresa' 
	
	set @whereStatement=' where plantillas_caja.idempresa= ' + convert(varchar(10),@idEmpresa) + 
						' and plantillas_caja.plantilla_id=' + convert(varchar(10),@idPlantilla) +
						' and plantillas_caja.ocupacion=' + convert(varchar(10),@idPuesto) +
						' and plantillas_caja.centro=' + @centro
	
	if @idCaja<>0 
		begin
			set @whereStatement=' and plantillas_caja.idcaja= ' + convert(varchar(10),@idcaja)
		end
		
	exec (@selectStatement  + @fromStatement  + @whereStatement)

GO


/**************************************************************************************************
 * Name          : plantillasEliminaPlantilla
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 8 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasInsertaCaja'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasInsertaCaja
GO

CREATE PROCEDURE dbo.plantillasInsertaCaja
(	@idEmpresa as bigint
   ,@plantilla_id as bigint
   ,@codigo as bigint
   ,@fechaInicio as datetime
   ,@fechaFinal as datetime
   ,@Sueldo as decimal(18,2)
   ,@idcaja as bigint
   ,@estatus as varchar(10)
   ,@centro as varchar(250)
   ,@ocupacion as bigint)
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY
    
    if @idcaja=0
		begin
		INSERT INTO plantillas_caja
           (idEmpresa
           ,plantilla_id
           ,codigo
           ,fechaInicio
           ,fechaFinal
           ,Sueldo
           ,estatus
           ,centro
           ,ocupacion)
		VALUES
           (@idEmpresa
           ,@plantilla_id
           ,@codigo
           ,@fechaInicio
           ,@fechaFinal
           ,@Sueldo
           ,@estatus
           ,@centro
           ,@ocupacion)
        end
	else
		begin
			UPDATE plantillas_caja
			   SET idEmpresa = @idEmpresa
				  ,plantilla_id = @plantilla_id
				  ,codigo = @codigo
				  ,fechaInicio = @fechainicio
				  ,fechaFinal = @fechafinal
				  ,Sueldo = @sueldo
				  ,estatus= @estatus
				  ,centro=@centro
				  ,ocupacion=@ocupacion
			 WHERE idcaja=@idcaja			
		end          
GO           



/**************************************************************************************************
 * Name          : plantillasEliminaPlantilla
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 8 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasEliminaCaja'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasEliminaCaja
GO

CREATE PROCEDURE dbo.plantillasEliminaCaja
(	@idEmpresa as bigint
   ,@plantilla_id as bigint
   ,@idcaja as bigint)
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY


	DELETE FROM plantillas_caja
	WHERE idCaja=@idcaja
	and idEmpresa=@idEmpresa
	and plantilla_id=@plantilla_id
      
GO        



/**************************************************************************************************
 * Name          : plantillasBusquedaEmpleado
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 8 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasBusquedaEmpleado'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasBusquedaEmpleado
GO

CREATE PROCEDURE dbo.plantillasBusquedaEmpleado
(	@idEmpresa as bigint,
	@idPuesto as bigint)
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY

	select convert(varchar(10),e.codigo) as codigo,
		e.nombre,
		e.ap_paterno,
		e.ap_materno,
		convert(varchar(10),m.empresa) as empresa,
		m.referencia,
		case e.activo
		when 'S' then 'Activo' else 'Baja'
		end as estatus
	from empleados e, empresas m, Llaves ll
	where e.empresa=m.empresa 
		and e.empresa=@idEmpresa
		and ll.codigo=e.codigo
		and ll.empresa=e.empresa
		and ll.ocupacion=@idPuesto

GO


/**************************************************************************************************
 * Name          : plantillasBusquedaEmpleado
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 8 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasObtenNombreEmpleado'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasObtenNombreEmpleado
GO

CREATE PROCEDURE dbo.plantillasObtenNombreEmpleado
(	@idEmpresa as bigint,
	@codigo as bigint,
	@idpuesto as bigint,
	@centro as varchar(250))
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY

	select rtrim(nombre) + ' ' + rtrim(ap_paterno) + ' ' + rtrim(ap_materno)		
	from empleados
	inner join Llaves on Llaves.empresa=empleados.empresa
	and Llaves.codigo=empleados.codigo
	where empleados.empresa=@idEmpresa
	and empleados.codigo=@codigo
	and Llaves.ocupacion=@idpuesto
	and llaves.centro=@centro

GO



IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'plantillasCargaListadoPlantillas'
                     AND type = 'P' )
     DROP PROCEDURE dbo.plantillasCargaListadoPlantillas 
GO

CREATE PROCEDURE dbo.plantillasCargaListadoPlantillas
(@idempresa bigint)

     WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
	Select	plantilla_id, 
			nombre 
	from plantillas 
	where empresa=@idempresa
	   
     END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO
/**********************************************************/

IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'plantillaReporteAuditoriaDePlazas'
                     AND type = 'P' )
     DROP PROCEDURE dbo.plantillaReporteAuditoriaDePlazas 
GO

CREATE PROCEDURE dbo.plantillaReporteAuditoriaDePlazas
(@idempresa bigint,
 @idPlantilla bigint)

     WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
    declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @orderStatement as varchar(2048)   
      
      
	set @selectStatement=' SELECT EMPRESAS.registro_patronal,
							EMPRESAS.rfc_empresa,
							EMPRESAS.nombre_empresa,
							PLANTILLAS.empresa,
							PLANTILLAS.plantilla_id,
							PLANTILLAS.nombre,
							plantillas_centros.centro,	
							centros.nomdepto,
							Plantillas_Puestos.ocupacion,
							Plantillas_Puestos.cantidad,
							TABULADOR.actividad,
							(   select COUNT(*) 
								from Llaves 
								left join empleados on empleados.codigo=llaves.codigo 
													and empleados.empresa=llaves.empresa
								where ocupacion=Plantillas_Puestos.ocupacion
								and centro=plantillas_centros.centro
								and empleados.activo=''S'') as EnNomina,
							TABULADOR.actividad,
							Plantillas_Puestos.cantidad -(select COUNT(*) 
								from Llaves 
								left join empleados on empleados.codigo=llaves.codigo 
														and empleados.empresa=llaves.empresa
								where ocupacion=Plantillas_Puestos.ocupacion
								and centro=plantillas_centros.centro
								and empleados.activo=''S'') as Disponibles
								'			
			
	set @fromStatement =' 	FROM EMPRESAS 
							inner JOIN PLANTILLAS ON EMPRESAS.EMPRESA=PLANTILLAS.empresa
							
							inner JOIN plantillas_centros ON plantillas_centros.empresa=PLANTILLAS.empresa
									AND plantillas_centros.plantilla_id=PLANTILLAS.plantilla_id	
									
							inner JOIN Plantillas_Puestos ON Plantillas_Puestos.empresa=plantillas_centros.empresa
									AND Plantillas_Puestos.plantilla_id=plantillas_centros.plantilla_id
									and plantillas_puestos.centro=plantillas_centros.centro
									
							inner JOIN tabulador ON tabulador.empresa=Plantillas_Puestos.empresa
									AND Plantillas_Puestos.ocupacion=tabulador.ocupacion
							
							inner JOIN centros ON centros.empresa=plantillas_centros.empresa
							AND plantillas_centros.centro=centros.centro'
							 
	 set @whereStatement =' WHERE PLANTILLAS.empresa='+ CONVERT(varchar(10), @idempresa)
	 if @idPlantilla<>0 
		set @whereStatement = @whereStatement + ' and PLANTILLAS.plantilla_id=' + CONVERT(varchar(10), @idplantilla)
	 
	 set @orderStatement = 'ORDER BY PLANTILLAS.plantilla_id'
	 
	 exec (@selectStatement+@fromStatement+@whereStatement+@orderStatement)
	 	   
     END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO


/**********************************************************/

IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'obtenReportePuestosDeLaPlantilla'
                     AND type = 'P' )
     DROP PROCEDURE dbo.obtenReportePuestosDeLaPlantilla 
GO

CREATE PROCEDURE dbo.obtenReportePuestosDeLaPlantilla
(@idempresa bigint,
 @idPlantilla bigint)

     WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
	declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @orderStatement as varchar(2048)   
      
      
	set @selectStatement=' SELECT EMPRESAS.registro_patronal,
							EMPRESAS.rfc_empresa,
							EMPRESAS.nombre_empresa,
							PLANTILLAS.empresa,
							PLANTILLAS.plantilla_id,
							PLANTILLAS.nombre,
							Plantillas_Puestos.ocupacion,
							Plantillas_Puestos.cantidad,
							TABULADOR.actividad,
							tabulador.garantia,
							nominas.tiponom,
							nominas.nomina,
							clases.clase,
							clases.nombre,
							centros.centro,
							centros.nomdepto,
							Plantillas_Puestos.cantidad '
						
	 set @fromStatement=' FROM EMPRESAS
							 LEFT JOIN PLANTILLAS ON EMPRESAS.EMPRESA=PLANTILLAS.empresa
							 LEFT JOIN Plantillas_Puestos ON Plantillas_Puestos.empresa=PLANTILLAS.empresa
										AND Plantillas_Puestos.plantilla_id=PLANTILLAS.plantilla_id
							 LEFT JOIN tabulador ON tabulador.empresa=Plantillas_Puestos.empresa
										AND Plantillas_Puestos.ocupacion=tabulador.ocupacion
							 LEFT JOIN centros on centros.centro = Plantillas_Puestos.centro 
										and centros.empresa=Plantillas_Puestos.empresa
							 LEFT JOIN nominas on nominas.tiponom = Plantillas_Puestos.tiponom 
										and nominas.empresa=Plantillas_Puestos.empresa
							 LEFT JOIN clases on clases.clase = Plantillas_Puestos.clase 
										and clases.empresa=Plantillas_Puestos.empresa'
					
	 set @whereStatement =' WHERE PLANTILLAS.empresa='+ CONVERT(varchar(10), @idempresa)
	 if @idPlantilla<>0 
		set @whereStatement = @whereStatement + ' and PLANTILLAS.plantilla_id=' + CONVERT(varchar(10), @idplantilla)
	 
	 set @orderStatement = ' ORDER BY PLANTILLAS.plantilla_id'
	 
	 
	 exec (@selectStatement+@fromStatement+@whereStatement+@orderStatement)
	 	   
     END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO


/**********************************************************/

IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'obtenReporteCentrosDeCostosPorPlantilla'
                     AND type = 'P' )
     DROP PROCEDURE dbo.obtenReporteCentrosDeCostosPorPlantilla 
GO

CREATE PROCEDURE dbo.obtenReporteCentrosDeCostosPorPlantilla
(@idempresa bigint,
 @idPlantilla bigint)

     WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
     
    declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @orderStatement as varchar(2048)   
      
      
	set @selectStatement=' SELECT EMPRESAS.registro_patronal,
							EMPRESAS.rfc_empresa,
							EMPRESAS.nombre_empresa,
							PLANTILLAS.empresa,
							PLANTILLAS.plantilla_id,
							PLANTILLAS.nombre,
							Plantillas_Puestos.ocupacion,
							Plantillas_Puestos.cantidad,
							TABULADOR.actividad,
							tabulador.garantia,
							nominas.tiponom,
							nominas.nomina,
							clases.clase,
							clases.nombre,
							centros.centro,
							centros.nomdepto,
							Plantillas_Puestos.cantidad '
						
	 set @fromStatement=' FROM EMPRESAS
							 LEFT JOIN PLANTILLAS ON EMPRESAS.EMPRESA=PLANTILLAS.empresa
							 LEFT JOIN Plantillas_Puestos ON Plantillas_Puestos.empresa=PLANTILLAS.empresa
										AND Plantillas_Puestos.plantilla_id=PLANTILLAS.plantilla_id
							 LEFT JOIN tabulador ON tabulador.empresa=Plantillas_Puestos.empresa
										AND Plantillas_Puestos.ocupacion=tabulador.ocupacion
							 LEFT JOIN centros on centros.centro = Plantillas_Puestos.centro 
										and centros.empresa=Plantillas_Puestos.empresa
							 LEFT JOIN nominas on nominas.tiponom = Plantillas_Puestos.tiponom 
										and nominas.empresa=Plantillas_Puestos.empresa
							 LEFT JOIN clases on clases.clase = Plantillas_Puestos.clase 
										and clases.empresa=Plantillas_Puestos.empresa'
					
	 set @whereStatement =' WHERE PLANTILLAS.empresa='+ CONVERT(varchar(10), @idempresa)
	 if @idPlantilla<>0 
		set @whereStatement = @whereStatement + ' and PLANTILLAS.plantilla_id=' + CONVERT(varchar(10), @idplantilla)
	 
	 set @orderStatement = ' ORDER BY PLANTILLAS.plantilla_id'	 
	 
	 exec (@selectStatement+@fromStatement+@whereStatement+@orderStatement)    
	 	   
     END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO


/**********************************************************/

IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'obtenReporteEmpleadosPorPlantilla'
                     AND type = 'P' )
     DROP PROCEDURE dbo.obtenReporteEmpleadosPorPlantilla 
GO

CREATE PROCEDURE dbo.obtenReporteEmpleadosPorPlantilla
(@idempresa bigint,
 @idPlantilla bigint)

     WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @orderStatement as varchar(2048)   
      
      
	set @selectStatement=' SELECT EMPRESAS.registro_patronal,
							EMPRESAS.rfc_empresa,
							EMPRESAS.nombre_empresa,
							PLANTILLAS.empresa,
							PLANTILLAS.plantilla_id,
							PLANTILLAS.nombre,
							Plantillas_Puestos.ocupacion,
							Plantillas_Puestos.cantidad,
							TABULADOR.actividad,
							tabulador.garantia,
							nominas.tiponom,
							nominas.nomina,
							clases.clase,
							clases.nombre,
							centros.centro,
							centros.nomdepto,
							Plantillas_Puestos.cantidad '
						
	 set @fromStatement=' FROM EMPRESAS
							 LEFT JOIN PLANTILLAS ON EMPRESAS.EMPRESA=PLANTILLAS.empresa
							 LEFT JOIN Plantillas_Puestos ON Plantillas_Puestos.empresa=PLANTILLAS.empresa
										AND Plantillas_Puestos.plantilla_id=PLANTILLAS.plantilla_id
							 LEFT JOIN tabulador ON tabulador.empresa=Plantillas_Puestos.empresa
										AND Plantillas_Puestos.ocupacion=tabulador.ocupacion
							 LEFT JOIN centros on centros.centro = Plantillas_Puestos.centro 
										and centros.empresa=Plantillas_Puestos.empresa
							 LEFT JOIN nominas on nominas.tiponom = Plantillas_Puestos.tiponom 
										and nominas.empresa=Plantillas_Puestos.empresa
							 LEFT JOIN clases on clases.clase = Plantillas_Puestos.clase 
										and clases.empresa=Plantillas_Puestos.empresa
							 '
					
	 set @whereStatement =' WHERE PLANTILLAS.empresa='+ CONVERT(varchar(10), @idempresa)
	 if @idPlantilla<>0 
		set @whereStatement = @whereStatement + ' and PLANTILLAS.plantilla_id=' + CONVERT(varchar(10), @idplantilla)
	 
	 set @orderStatement = ' ORDER BY PLANTILLAS.plantilla_id '
	 	 
	 exec (@selectStatement + @fromStatement + @whereStatement + @orderStatement)
	 	   
     END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO



/**********************************************************/

IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'obtenReporteGeneralDePlantillas'
                     AND type = 'P' )
     DROP PROCEDURE dbo.obtenReporteGeneralDePlantillas 
GO

CREATE PROCEDURE dbo.obtenReporteGeneralDePlantillas
(@idempresa bigint,
 @idPlantilla bigint)

     WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
	declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @orderStatement as varchar(2048)   
      
      
	set @selectStatement=' select PLANTILLAS.empresa,
							PLANTILLAS.plantilla_id, 
							PLANTILLAS.nombre, 
							case PLANTILLAS.idtipo 
							when ''P'' then ''Permanente''
							when ''P'' then ''Temporal'' end as tipoPlantilla,
							convert(varchar(10),PLANTILLAS.fechainicio,103) as fechainicio,
							convert(varchar(10),PLANTILLAS.fechafinal,103) as fechafinal,
							case PLANTILLAS.activa 
							when ''N'' then ''Inactiva''
							else ''Activa'' end as estatus '
						
	 set @fromStatement=' FROM EMPRESAS
							 LEFT JOIN PLANTILLAS ON EMPRESAS.EMPRESA=PLANTILLAS.empresa
						'
					
	 set @whereStatement =' WHERE PLANTILLAS.empresa='+ CONVERT(varchar(10), @idempresa)
	 if @idPlantilla<>0 
		set @whereStatement = @whereStatement + ' and PLANTILLAS.plantilla_id=' + CONVERT(varchar(10), @idplantilla)
	 
	 set @orderStatement = ' ORDER BY PLANTILLAS.plantilla_id'
	 
	 
	 exec (@selectStatement+@fromStatement+@whereStatement+@orderStatement)
	 	   
     END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO



/**********************************************************/

IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'llenaListadoPlantillasPuestos'
                     AND type = 'P' )
     DROP PROCEDURE dbo.llenaListadoPlantillasPuestos 
GO

CREATE PROCEDURE dbo.llenaListadoPlantillasPuestos
(@idempresa bigint,
 @idPlantilla bigint,
 @centroCostos bigint)

 WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
	declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @orderStatement as varchar(2048) 

	Select  convert(varchar(10),plantillas_puestos.ocupacion) + '-' + tabulador.actividad, 
			plantillas_puestos.sueldo, 
			plantillas_puestos.cantidad,
             plantillas_puestos.clase + '-' + clases.nombre, 
			  convert(varchar(10),plantillas_puestos.horario) + '-' + horarios_catalogo.nombre, 
             case plantillas_puestos.sindicato when 'N' then 'No' else 'Si' end as sindicato, 
			 case plantillas_puestos.reqautorizacion when 'N' then 'No' else 'Si' end as requiereAutorizacion,
			 plantillas_puestos.nivelautorizacion,
             plantillas_puestos.autorizador1,
			 plantillas_puestos.autorizador2,
			 plantillas_puestos.autorizador3,
			 plantillas_puestos.autorizador4,
             plantillas_puestos.centro,
			 nominas.tiponom
             from plantillas_puestos   
				left join tabulador on plantillas_puestos.ocupacion=tabulador.ocupacion and plantillas_puestos.empresa=tabulador.empresa
				left join clases on plantillas_puestos.empresa=clases.empresa and plantillas_puestos.clase=clases.clase			
				left join nominas on plantillas_puestos.empresa=nominas.empresa and plantillas_puestos.tiponom=nominas.tiponom
				left join horarios_catalogo on plantillas_puestos.empresa=horarios_catalogo.empresa and plantillas_puestos.horario=horarios_catalogo.horario
             where plantillas_puestos.empresa=@idempresa
             and plantillas_puestos.plantilla_id=@idplantilla
             and plantillas_puestos.centro=@centroCostos            
             order by plantillas_puestos.ocupacion

	END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO



/**************************************************************************************************
 * Name          : plantillasBusquedaEmpleado
 * Project       : Plantillas
 * Description   : genera reporte de centros de costos por plantillas
 * Table name    : 
 * Copyright     : Apsi 2009 - 2014. All rights reserved
 * Company       : APSI, S.A. De C.V.
 * Author        : Margarita Valdez (margarita@apsi.com.mx)
 * Creation date : 8 agosto  2016
 **************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasReporteCaja'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasReporteCaja
GO

CREATE PROCEDURE dbo.plantillasReporteCaja
(	@idEmpresa as bigint,
	@idPlantilla as bigint)
AS 
    SET NOCOUNT ON
    SET DATEFORMAT MDY        
	
	begin

	declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @groupStatement as varchar(2048)  
	declare @orderStatement as varchar(2048)   
      
      
	set @selectStatement='  Select 
							plantillas.plantilla_id, 
							centros.nomdepto,
							Plantillas_Centros.centro,
							plantillas_caja.idCaja,
							Plantillas_Puestos.ocupacion,
							tabulador.actividad,
							empleadocaja.codigo,
							plantillas.nombre as nombrePlantilla, 
							plantillas.idTipo,
							convert(varchar(10),plantillas.fechaInicio,103) as fechaInicial,
							convert(varchar(10),plantillas.fechafinal,103) as fechaFinal,
							plantillas_caja.estatus,
							DATEDIFF(dd,GETDATE(),plantillas.fechafinal) as tiempovacante,
							plantillas_caja.Sueldo,
							rtrim(empleadocaja.nombre) + '' '' + rtrim(empleadocaja.ap_paterno) + '' '' + rtrim(empleadocaja.ap_materno) as nombreempleado,
							llaves.supervisor,
							rtrim(empleadossupervisor.nombre) + '' '' + rtrim(empleadossupervisor.ap_paterno) + '' '' + rtrim(empleadossupervisor.ap_materno) as nombresupervisor'

	set @fromStatement='	from plantillas
						inner join plantillas_caja on plantillas_caja.idEmpresa=plantillas.empresa
							and plantillas_caja.plantilla_id=plantillas.plantilla_id
			
						inner join Llaves on Llaves.empresa=plantillas_caja.idempresa
							and Llaves.codigo=plantillas_caja.codigo

						inner join Plantillas_Centros on plantillas_caja.plantilla_id=Plantillas_Centros.plantilla_id
							and plantillas_caja.idempresa=Plantillas_Centros.empresa
							and Plantillas_Centros.centro=plantillas_caja.centro
			
							left join centros on centros.centro=Plantillas_Centros.centro
								and centros.empresa=Plantillas_Centros.empresa
			
						inner join Plantillas_Puestos on Plantillas_Puestos.plantilla_id=plantillas_caja.plantilla_id
							and plantillas_puestos.empresa=plantillas_caja.idEmpresa
							and Plantillas_Puestos.centro=Plantillas_Centros.centro
			
							inner join tabulador on  tabulador.empresa=plantillas.empresa
							and tabulador.ocupacion=plantillas_puestos.ocupacion	
							and llaves.ocupacion=Plantillas_Puestos.ocupacion
			
						inner join empleados empleadocaja on empleadocaja.codigo=llaves.codigo
							and empleadocaja.empresa=llaves.Empresa
			
						left join empleados empleadossupervisor on empleadossupervisor.codigo=llaves.supervisor
							and empleadossupervisor.empresa=llaves.Empresa	
							and llaves.codigo=empleadocaja.codigo'	
	 
	 
	 set @whereStatement =' WHERE PLANTILLAS.empresa='+ CONVERT(varchar(10), @idempresa)
	 if @idPlantilla<>0 
		set @whereStatement = @whereStatement + ' and PLANTILLAS.plantilla_id=' + CONVERT(varchar(10), @idplantilla)
	 
		
	set @groupStatement='	group by plantillas.plantilla_id, 
							centros.nomdepto,
							Plantillas_Centros.centro,
							Plantillas_Puestos.ocupacion,
							plantillas_caja.idCaja,
							tabulador.actividad,
							empleadocaja.codigo,
							plantillas.nombre, 
							plantillas.idTipo,
							plantillas.fechaInicio,
							plantillas.fechafinal,
							plantillas_caja.estatus,
							plantillas_caja.Sueldo,
							rtrim(empleadocaja.nombre) + '' '' + rtrim(empleadocaja.ap_paterno) + '' '' + rtrim(empleadocaja.ap_materno),
							Llaves.supervisor,
							rtrim(empleadossupervisor.nombre) + '' '' + rtrim(empleadossupervisor.ap_paterno) + '' '' + rtrim(empleadossupervisor.ap_materno)'


	set @orderStatement='	order by centro,ocupacion, codigo'

		
	 exec (@selectStatement+@fromStatement+@whereStatement+@groupStatement+@orderStatement)
            
    end
GO
/**********************************************************/

IF EXISTS ( SELECT  name
             FROM    dbo.sysobjects
             WHERE   name = 'plantillaReporteAuditoriaFaltantesDisponibles'
                     AND type = 'P' )
     DROP PROCEDURE dbo.plantillaReporteAuditoriaFaltantesDisponibles 
GO

CREATE PROCEDURE dbo.plantillaReporteAuditoriaFaltantesDisponibles
	(@idempresa bigint,
	 @idPlantilla bigint,
	 @tipo as varchar(15))

     WITH ENCRYPTION
AS
     SET NOCOUNT ON
     SET DATEFORMAT MDY
     SET XACT_ABORT ON
     BEGIN TRANSACTION
     BEGIN TRY
     
    declare @selectStatement as varchar(2048) 
    declare @fromStatement as varchar(2048) 
    declare @whereStatement as varchar(2048) 
    declare @orderStatement as varchar(2048) 
    
    create table #Temp
	(
		registro_patronal varchar(50),
		rfc_empresa varchar(50),
		nombre_empresa varchar(500),
		empresa bigint,
		plantilla_id bigint,
		nombrePlantilla varchar(500),
		centro varchar(50),	
		nomdepto varchar(500),
		ocupacion int,
		cantidad bigint,
		actividad varchar(100),
		EnNomina bigint,
		disponibles bigint
							 
	)  
      
	set @selectStatement=' SELECT EMPRESAS.registro_patronal,
							EMPRESAS.rfc_empresa,
							EMPRESAS.nombre_empresa,
							PLANTILLAS.empresa,
							PLANTILLAS.plantilla_id,
							PLANTILLAS.nombre,
							plantillas_centros.centro,	
							centros.nomdepto,
							Plantillas_Puestos.ocupacion,
							Plantillas_Puestos.cantidad,
							TABULADOR.actividad,
							(   select COUNT(*) 
								from Llaves 
								left join empleados on empleados.codigo=llaves.codigo 
													and empleados.empresa=llaves.empresa
								where ocupacion=Plantillas_Puestos.ocupacion
								and centro=plantillas_centros.centro
								and empleados.activo=''S'') as EnNomina,
							Plantillas_Puestos.cantidad -(select COUNT(*) 
								from Llaves 
								left join empleados on empleados.codigo=llaves.codigo 
														and empleados.empresa=llaves.empresa
								where ocupacion=Plantillas_Puestos.ocupacion
								and centro=plantillas_centros.centro
								and empleados.activo=''S'') as Disponibles
								'			
			
	set @fromStatement =' 	FROM EMPRESAS 
							inner JOIN PLANTILLAS ON EMPRESAS.EMPRESA=PLANTILLAS.empresa
							
							inner JOIN plantillas_centros ON plantillas_centros.empresa=PLANTILLAS.empresa
									AND plantillas_centros.plantilla_id=PLANTILLAS.plantilla_id	
									
							inner JOIN Plantillas_Puestos ON Plantillas_Puestos.empresa=plantillas_centros.empresa
									AND Plantillas_Puestos.plantilla_id=plantillas_centros.plantilla_id
									and plantillas_puestos.centro=plantillas_centros.centro
									
							inner JOIN tabulador ON tabulador.empresa=Plantillas_Puestos.empresa
									AND Plantillas_Puestos.ocupacion=tabulador.ocupacion
							
							inner JOIN centros ON centros.empresa=plantillas_centros.empresa
							AND plantillas_centros.centro=centros.centro'
							 
	 set @whereStatement =' WHERE PLANTILLAS.empresa='+ CONVERT(varchar(10), @idempresa)
	 if @idPlantilla<>0 
		set @whereStatement = @whereStatement + ' and PLANTILLAS.plantilla_id=' + CONVERT(varchar(10), @idplantilla)
	 
	 set @orderStatement = ' ORDER BY PLANTILLAS.plantilla_id'
	 
	 insert into #Temp exec (@selectStatement+@fromStatement+@whereStatement+@orderStatement)
	 
	 if @tipo='Excedentes'
		begin
			select * from #temp where disponibles<0
		end
	 else if @tipo='Faltantes'
		begin
			select * from #temp where disponibles>0
	 	end 
	 	
	 	
	 	  
     END TRY
     BEGIN CATCH

         IF ( XACT_STATE() ) = -1
             OR @@TRANCOUNT > 0
             ROLLBACK TRANSACTION

         SELECT  ERROR_NUMBER() AS ErrorNumber ,
                 ERROR_SEVERITY() AS ErrorSeverity ,
                 ERROR_STATE() AS ErrorState ,
                 ISNULL(ERROR_PROCEDURE(), '') AS ErrorProcedure ,
                 ERROR_LINE() AS ErrorLine ,
                 ERROR_MESSAGE() AS ErrorMessage

     END CATCH

     IF @@TRANCOUNT > 0
         COMMIT TRANSACTION

GO

      
/**************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasCreaPlantillaActual'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasCreaPlantillaActual
GO

CREATE PROCEDURE dbo.plantillasCreaPlantillaActual
	(@idEmpresa bigint)
    
AS 

BEGIN

    SET NOCOUNT ON
    SET DATEFORMAT MDY
    
	if NOT exists (select plantilla_id from plantillas where nombre='ACTUAL')
	   Insert into PLANTILLAs(empresa,NOMBRE,idtipo,fechainicio,fechafinal,staffing,activa) values (@idEmpresa,'ACTUAL','P',GETDATE(), GETDATE(),'N','S')
			
END
GO  

/**************************************************************************************************/

if exists (select * from dbo.sysobjects where id = object_id(N'dbo.PlantillasObtenCantidadPuestos') and xtype in (N'FN', N'IF', N'TF'))
	drop function dbo.PlantillasObtenCantidadPuestos
GO

CREATE FUNCTION [dbo].[PlantillasObtenCantidadPuestos](@idEmpresa bigint, @idPuesto bigint)
RETURNS bigint

AS

BEGIN

  DECLARE @cantidad bigint

   select @cantidad= ISNULL( count(empleados.codigo),0)
	 from empleados
		left join llaves on empleados.empresa=llaves.empresa and empleados.codigo=llaves.codigo
		left join tabulador on llaves.empresa=tabulador.empresa and tabulador.ocupacion=llaves.ocupacion 
		left join centros on llaves.centro=centros.centro and llaves.empresa=centros.empresa
	 where empleados.empresa=@idempresa
	 and empleados.activo='S'
	 and llaves.ocupacion=@idPuesto
	 group by tabulador.ocupacion

  RETURN(@cantidad)

END
go
      
/**************************************************************************************************/
IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasCargaPlantillaActual'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasCargaPlantillaActual
GO

CREATE PROCEDURE dbo.plantillasCargaPlantillaActual
	(@idEmpresa bigint)
    
AS 

BEGIN

    SET NOCOUNT ON
    SET DATEFORMAT MDY
    
    declare @idPlantilla bigint
    
    create table #centro (centro char(15),empresa bigint, idPlantilla bigint)
    create table #puesto (  ocupacion int,
							empresa numeric(3, 0),
							plantilla_id bigint,
							cantidad int,
							disponibles int,
							clase char(2),
							horario int,
							tiposal int,
							sueldo decimal(12, 2),
							sindicato char(1),
							varia_imss decimal(8, 2),
							reqAutorizacion char(1),
							nivelAutorizacion int,
							autorizador1 varchar(50),
							autorizador2 varchar(50),
							autorizador3 varchar(50),
							autorizador4 varchar(50),
							centro char(15),
							tiponom int)
  
	if exists(select plantilla_id from plantillas where nombre='ACTUAL' and empresa=@idEmpresa)
		begin
			select @idPlantilla=isnull(Plantilla_id,0)
			from plantillas 
			where nombre='ACTUAL'
			AND empresa=@idempresa
			
		   insert into #centro               
			   select distinct(centros.centro), @idempresa, @idPlantilla
				 from empleados
					left join llaves on empleados.empresa=llaves.empresa and empleados.codigo=llaves.codigo
					left join tabulador on llaves.empresa=tabulador.empresa and tabulador.ocupacion=llaves.ocupacion 
					left join centros on llaves.centro=centros.centro and llaves.empresa=centros.empresa
				 where empleados.empresa=@idempresa
				 and empleados.activo='S'
				 
			insert into plantillas_centros select empresa,centro,idPlantilla from #centro	
			
			insert into plantillas_puestos               
			   select distinct(tabulador.ocupacion), 
						@idempresa, 
						@idPlantilla, 
						1,
						0,
						llaves.clase,
						llaves.horario int,
						empleados.tiposal ,
						empleados.sueldo,
						empleados.sindicato,
						empleados.varia_imss,
						'N' ,
						0 ,
						'',
						'',
						'',
						'',
						llaves.centro,
						llaves.tiponom int	
				 from empleados
					left join llaves on empleados.empresa=llaves.empresa and empleados.codigo=llaves.codigo
					left join tabulador on llaves.empresa=tabulador.empresa and tabulador.ocupacion=llaves.ocupacion 
					left join centros on llaves.centro=centros.centro and llaves.empresa=centros.empresa
				 where empleados.empresa=@idempresa
				 and empleados.activo='S'
		end         
                   
     /*select empleados.empresa,
     			empleados.codigo,
     			rtrim(isnull(empleados.nombre,'')) + ' ' + rtrim(isnull(empleados.ap_paterno,'')) + ' ' + rtrim(isnull(empleados.ap_materno,'')),
     			tabulador.ocupacion,
     			tabulador.actividad,
     			centros.centro,
     			centros.nomdepto,
     			llaves.tiponom
     from empleados
		left join llaves on empleados.empresa=llaves.empresa and empleados.codigo=llaves.codigo
		left join tabulador on llaves.empresa=tabulador.empresa and tabulador.ocupacion=llaves.ocupacion 
		left join centros on llaves.centro=centros.centro and llaves.empresa=centros.empresa
     where empleados.empresa=6
     and empleados.activo='S'
     order b*/
         
END
GO
          
/**************************************************************************************/

IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasInsertaTodosCentrosCostos'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasInsertaTodosCentrosCostos
GO

CREATE PROCEDURE dbo.plantillasInsertaTodosCentrosCostos
	(@idEmpresa bigint,
	@idPlantilla bigint)
    
AS 

BEGIN

    SET NOCOUNT ON
    SET DATEFORMAT MDY
    
    insert into Plantillas_Centros 
		select @idempresa, c.centro, @idPlantilla 
		from centros c 
		where empresa=@idempresa 
		and NOT EXISTS (SELECT @idempresa, centro, @idPlantilla 
						FROM Plantillas_Centros
						WHERE empresa=@idempresa 
						and plantilla_id=@idPlantilla 
						and centro=c.centro)
        
END
GO


          
/**************************************************************************************/

IF EXISTS ( SELECT  name
            FROM    dbo.sysobjects
            WHERE   name = 'plantillasEliminaTodosCentrosCostos'
                    AND type = 'P' ) 
    DROP PROCEDURE dbo.plantillasEliminaTodosCentrosCostos
GO

CREATE PROCEDURE dbo.plantillasEliminaTodosCentrosCostos
	(@idEmpresa bigint,
	@idPlantilla bigint)
    
AS 

BEGIN

    SET NOCOUNT ON
    SET DATEFORMAT MDY
    
    delete from plantillas_caja where plantilla_id=@idplantilla and idempresa=@idEmpresa
    delete from plantillas_puestos where plantilla_id=@idplantilla and empresa=@idEmpresa
    delete from plantillas_centros where plantilla_id=@idplantilla and empresa=@idEmpresa
   
END
GO
    
    
    
/**************************************************************************************/